
Tab-completion with custom (domain-specific) arg values is<br/>
constantly on a dev wish list for complex backend.

*   DEC 2022: Attempts to find an adequate existing solution for sizeable custom data yielded no results.<br/>
    However, the initial POC showed viable approach with all parts integrated.

*   JAN 2023: The [earlier question][earlier_stack_question] for alternatives received zero activity for a month<br/>
    (auto-deleted by a bot due to a single silent downvote).<br/>
    Community request to restore it was &#127925; Shut Down In Flames.
    <!--
    It "seeked recommendations" which tend to be spammed by answers<br/>
    (controversially, some spam in that case may actually help more than none).
    -->
  
*   FEB 2023: The [explanation hangs on the appropriate site][later_stack_question] now -<br/>
    recommendations are still very welcome there.<br/>
    But, with some patience for integration, `argrelay` itself already became satisfying enough.

*   MAR 2023: continue with [`release_notes`][release_notes]...

[earlier_stack_question]: https://stackoverflow.com/q/74996560/441652
[later_stack_question]: https://softwarerecs.stackexchange.com/questions/85247/
[release_notes]: ../release_notes/readme.md
